@@ -5,10 +5,8 @@ from inspect import getmembers, ismethod
 
 
 from mio import runtime
-from mio.states import NormalState
 from mio.errors import AttributeError, TypeError
 from mio.utils import format_object, method, Null
-from mio.states import BreakState, ContinueState, ReturnState
 
 
 class Object(object):
@@ -26,7 +24,10 @@ class Object(object):
         self.behaviors = {}
 
         self.binding = None
-        self.state = NormalState()
+
+        from mio.core.state import State
+        if self.__class__ is not State:
+            self.state = State()
 
         if methods:
             self.create_methods()
@@ -104,7 +105,11 @@ class Object(object):
         obj.traits = []
         obj.behaviors = {}
 
-        obj.state = NormalState()
+        self.binding = None
+
+        from mio.core.state import State
+        if self.__class__ is not State:
+            self.state = State()
 
         return obj
 
@@ -119,27 +124,32 @@ class Object(object):
 
     @method("del")
     def _del(self, receiver, context, m, key):
-        key = key.eval(context)
+        key = str(key.eval(context))
+        value = receiver[key]
         del receiver[key]
+        if isinstance(value, Object):
+            value.bindig = None
         return runtime.find("None")
 
     @method()
     def has(self, receiver, context, m, key):
-        key = key.eval(context)
+        key = str(key.eval(context))
         if key in receiver:
             return runtime.find("True")
         return runtime.find("False")
 
     @method()
     def set(self, receiver, context, m, key, value):
-        key = key.eval(context)
+        key = str(key.eval(context))
         value = value.eval(context)
+        if isinstance(value, Object):
+            value.binding = key
         receiver[key] = value
         return value
 
     @method()
     def get(self, receiver, context, m, key, default=None):
-        key = key.eval(context)
+        key = str(key.eval(context))
         default = default.eval(context) if default else runtime.find("None")
         return receiver.attrs.get(key, default)
 
@@ -206,70 +216,12 @@ class Object(object):
         from mio.core.block import Block
         return Block(body, args, kwargs)
 
-    # Flow Control
-
-    @method()
-    def foreach(self, receiver, context, m, *args):
-        try:
-            result = runtime.find("None")
-            vars, expression = args[:-1], args[-1]
-
-            for item in receiver:
-                if len(vars) == 2:
-                    context[vars[0].name], context[vars[1].name] = item
-                elif len(vars) == 1:
-                    context[vars[0].name] = item
-
-                result = expression.eval(context)
-
-                if context.state.stop:
-                    if context.state.isContinue:
-                        context.state = NormalState()
-                        continue
-                    else:
-                        return context.state.returnValue
-            return result
-        finally:
-            if not context.state.isReturn:
-                context.state = NormalState()
-
-    @method("while")
-    def _while(self, receiver, context, m, condition, expression):
-        try:
-            result = runtime.find("None")
-
-            while condition.eval(context):
-                result = expression.eval(context)
-
-                if context.state.stop:
-                    if context.state.isContinue:
-                        context.state = NormalState()
-                        continue
-                    else:
-                        return context.state.returnValue
-            return result
-        finally:
-            if not context.state.isReturn:
-                context.state = NormalState()
-
-    @method("continue")
-    def _continue(self, receiver, context, m):
-        context.state = ContinueState()
-        return runtime.find("None")
-
-    @method("break")
-    def _break(self, reciver, context, m):
-        context.state = BreakState()
-        return runtime.find("None")
-
-    @method("return")
-    def _return(self, receiver, context, m, *args):
-        value = args[0].eval(context) if args else runtime.find("None")
-        context.state = ReturnState(value)
-        return receiver
-
     # Introspection
 
+    @method("state")
+    def getState(self, receiver, context, m):
+        return receiver.state
+
     @method("type")
     def getType(self, receiver, context, m):
         return runtime.find("String").clone(receiver.type)
@@ -291,8 +243,9 @@ class Object(object):
         return runtime.find("Number").clone(hash(receiver))
 
     @method()
-    def id(self, receiver, context, m):
-        return runtime.find("Number").clone(id(receiver))
+    def id(self, receiver, context, m, obj=None):
+        obj = obj.eval(context) if obj is not None else receiver
+        return runtime.find("Number").clone(id(obj))
 
     @method()
     def keys(self, receiver, context, m):
@@ -317,7 +270,7 @@ class Object(object):
 
     @method()
     def evalArg(self, receiver, context, m, arg):
-        return arg.eval(receiver, context)
+        return arg.eval(context)
 
     @method()
     def do(self, receiver, context, m, expression):
@@ -328,13 +281,11 @@ class Object(object):
     def _clone(self, receiver, context, m, *args):
         object = receiver.clone()
 
-        if m.first.previous.name == "set":
-            object.binding = m.first.previous.args[0].name
-
         try:
             m = runtime.find("Message").clone()
             m.name = "init"
             m.args = args
+            m.call = True
             m.eval(object, context, m)
         except AttributeError:
             pass
