@@ -5,7 +5,7 @@ from mio.object import Object
 
 class String(Object):
 
-    def __init__(self, value=""):
+    def __init__(self, value=u""):
         super(String, self).__init__(value=value)
 
         self.create_methods()
@@ -30,12 +30,15 @@ class String(Object):
     def __repr__(self):
         return repr(self.value)
 
+    def __bytes__(self):
+        return self.value.encode("utf-8")
+
     def __str__(self):
         return str(self.value)
 
     @method()
     def init(self, receiver, context, m, value=None):
-        receiver.value = value.eval(context) if value is not None else ""
+        receiver.value = value.eval(context) if value is not None else u""
 
     # General Operations
 
